/************************************************************************************
*                                                                                   *
*   File Name   : LED_DISP_DRV.c                                                    *
*   Contents    : LED-Dot-matrix-Display-Driver for Sanduhr                         *
*   Version     : 1.17                                                               *
*************************************************************************************/ 

#include "globals.h"
#include "max7221.h"


/* Constant Definitions for the Sanduhr-Pages showing the rinsing sand */
/* First dimension of the Array is the number of pages (62), second one */
/* is the number of columns (5) */
/*
const unsigned char disp1[62][5] = {
                                   { col0,  col1,  col2,  col3, col4 }, <<page  1>>
                                   { col0,  col1,  col2,  col3, col4 }, <<page  2>>
                                   ...........
*/


const unsigned char disp1_up[62][5] = {
                                      { 31,  63,  63,  63, 127}, /* page  1 */
                                      { 31,  63,  63,  63, 127}, /* page  2 */
                                      { 31,  63,  63,  63, 125}, /* page  3 */
                                      { 31,  63,  63,  63, 121}, /* page  4 */
                                      { 31,  63,  63,  63, 121}, /* page  5 */
                                      { 31,  63,  63,  63, 121}, /* page  6 */
                                      { 31,  63,  63,  61, 121}, /* page  7 */
                                      { 31,  63,  61,  61, 121}, /* page  8 */
                                      { 31,  63,  61,  61, 121}, /* page  9 */
                                      { 31,  63,  61,  61, 113}, /* page 10 */
                                      { 31,  63,  61,  57, 113}, /* page 11 */
                                      { 31,  63,  61,  57, 113}, /* page 12 */
                                      { 31,  63,  61,  57, 113}, /* page 13 */
                                      { 31,  63,  61,  57, 112}, /* page 14 */
                                      { 31,  63,  61,  57, 112}, /* page 15 */
                                      { 31,  63,  61,  49, 112}, /* page 16 */
                                      { 31,  63,  61,  49, 112}, /* page 17 */
                                      { 31,  63,  57,  49, 112}, /* page 18 */
                                      { 31,  63,  57,  49, 112}, /* page 19 */
                                      { 31,  63,  57,  49, 112}, /* page 20 */
                                      { 31,  61,  57,  49, 112}, /* page 21 */
                                      { 31,  61,  57,  49, 112}, /* page 22 */
                                      { 29,  61,  57,  49, 112}, /* page 23 */
                                      { 29,  57,  57,  49, 112}, /* page 24 */
                                      { 29,  57,  57,  49, 112}, /* page 25 */
                                      { 29,  57,  49,  49, 112}, /* page 26 */
                                      { 29,  57,  49,  49, 112}, /* page 27 */
                                      { 29,  57,  49,  49, 112}, /* page 28 */
                                      { 25,  57,  49,  49, 112}, /* page 29 */
                                      { 25,  57,  49,  49, 112}, /* page 30 */
                                      { 25,  57,  49,  48, 112}, /* page 31 */
                                      { 25,  49,  49,  48, 112}, /* page 32 */
                                      { 25,  49,  49,  48, 112}, /* page 33 */
                                      { 25,  49,  49,  48,  96}, /* page 34 */
                                      { 25,  49,  49,  48,  96}, /* page 35 */
                                      { 17,  49,  49,  48,  96}, /* page 36 */
                                      { 17,  49,  49,  48,  96}, /* page 37 */
                                      { 17,  49,  48,  48,  96}, /* page 38 */
                                      { 17,  49,  48,  48,  96}, /* page 39 */
                                      { 17,  49,  48,  48,  96}, /* page 40 */
                                      { 17,  49,  48,  32,  96}, /* page 41 */
                                      { 17,  48,  48,  32,  96}, /* page 42 */
                                      { 17,  48,  48,  32,  96}, /* page 43 */
                                      { 17,  48,  32,  32,  96}, /* page 44 */
                                      { 17,  48,  32,  32,  96}, /* page 45 */
                                      { 17,  48,  32,  32,  96}, /* page 46 */
                                      { 16,  48,  32,  32,  96}, /* page 47 */
                                      { 16,  48,  32,  32,  96}, /* page 48 */
                                      { 16,  32,  32,  32,  96}, /* page 49 */
                                      { 16,  32,  32,  32,  96}, /* page 50 */
                                      { 16,  32,  32,  32,  64}, /* page 51 */
                                      { 16,  32,  32,  32,  64}, /* page 52 */
                                      {  0,  32,  32,  32,  64}, /* page 53 */
                                      {  0,   0,  32,  32,  64}, /* page 54 */
                                      {  0,   0,  32,  32,  64}, /* page 55 */
                                      {  0,   0,   0,  32,  64}, /* page 56 */
                                      {  0,   0,   0,  32,  64}, /* page 57 */
                                      {  0,   0,   0,   0,  64}, /* page 58 */
                                      {  0,   0,   0,   0,  64}, /* page 59 */
                                      {  0,   0,   0,   0,   0}, /* page 60 */
                                      {  0,   0,   0,   0,   0}, /* page 61 */
                                      {  0,   0,   0,   0, 127}  /* page 62, horizontal line */
                                      };

const unsigned char disp3_up[62][5] = {
                                      {127,  63,  63,  63,  31}, /* page  1 */
                                      {125,  63,  63,  63,  31}, /* page  2 */
                                      {125,  63,  63,  63,  31}, /* page  3 */
                                      {125,  63,  63,  63,  31}, /* page  4 */
                                      {121,  63,  63,  63,  31}, /* page  5 */
                                      {121,  61,  63,  63,  31}, /* page  6 */
                                      {121,  61,  63,  63,  31}, /* page  7 */
                                      {121,  61,  63,  63,  31}, /* page  8 */
                                      {121,  61,  61,  63,  31}, /* page  9 */
                                      {121,  61,  61,  63,  31}, /* page 10 */
                                      {121,  61,  61,  63,  31}, /* page 11 */
                                      {113,  61,  61,  63,  31}, /* page 12 */
                                      {113,  57,  61,  63,  31}, /* page 13 */
                                      {113,  57,  61,  63,  31}, /* page 14 */
                                      {112,  57,  61,  63,  31}, /* page 15 */
                                      {112,  57,  61,  63,  31}, /* page 16 */
                                      {112,  49,  61,  63,  31}, /* page 17 */
                                      {112,  49,  61,  63,  31}, /* page 18 */
                                      {112,  49,  57,  63,  31}, /* page 19 */
                                      {112,  49,  57,  61,  31}, /* page 20 */
                                      {112,  49,  57,  61,  31}, /* page 21 */
                                      {112,  49,  57,  61,  29}, /* page 22 */
                                      {112,  49,  57,  61,  29}, /* page 23 */
                                      {112,  49,  57,  61,  29}, /* page 24 */
                                      {112,  49,  57,  57,  29}, /* page 25 */
                                      {112,  49,  57,  57,  29}, /* page 26 */
                                      {112,  49,  49,  57,  29}, /* page 27 */
                                      {112,  49,  49,  57,  25}, /* page 28 */
                                      {112,  49,  49,  57,  25}, /* page 29 */
                                      {112,  48,  49,  57,  25}, /* page 30 */
                                      {112,  48,  49,  57,  25}, /* page 31 */
                                      {112,  48,  49,  57,  25}, /* page 32 */
                                      {112,  48,  49,  49,  25}, /* page 33 */
                                      {112,  48,  49,  49,  25}, /* page 34 */
                                      { 96,  48,  49,  49,  25}, /* page 35 */
                                      { 96,  48,  49,  49,  25}, /* page 36 */
                                      { 96,  48,  49,  49,  17}, /* page 37 */
                                      { 96,  48,  49,  49,  17}, /* page 38 */
                                      { 96,  48,  48,  49,  17}, /* page 39 */
                                      { 96,  32,  48,  49,  17}, /* page 40 */
                                      { 96,  32,  48,  49,  17}, /* page 41 */
                                      { 96,  32,  48,  49,  17}, /* page 42 */
                                      { 96,  32,  48,  48,  17}, /* page 43 */
                                      { 96,  32,  48,  48,  17}, /* page 44 */
                                      { 96,  32,  32,  48,  17}, /* page 45 */
                                      { 96,  32,  32,  48,  16}, /* page 46 */
                                      { 96,  32,  32,  48,  16}, /* page 47 */
                                      { 96,  32,  32,  32,  16}, /* page 48 */
                                      { 96,  32,  32,  32,  16}, /* page 49 */
                                      { 64,  32,  32,  32,  16}, /* page 50 */
                                      { 64,  32,  32,  32,  16}, /* page 51 */
                                      { 64,  32,  32,  32,   0}, /* page 52 */
                                      { 64,  32,  32,  32,   0}, /* page 53 */
                                      { 64,  32,  32,  32,   0}, /* page 54 */
                                      { 64,  32,  32,   0,   0}, /* page 55 */
                                      { 64,  32,  32,   0,   0}, /* page 56 */
                                      { 64,  32,   0,   0,   0}, /* page 57 */
                                      { 64,  32,   0,   0,   0}, /* page 58 */
                                      { 64,   0,   0,   0,   0}, /* page 59 */
                                      { 64,   0,   0,   0,   0}, /* page 60 */
                                      {  0,   0,   0,   0,   0}, /* page 61 */
                                      {127,   0,   0,   0,   0}  /* page 62, horizontal line */
                                      };

const unsigned char disp1_hf[61][5] = {
                                      { 31,  63,  63,  63, 127}, /* page  1 */
                                      { 31,  63,  63,  63, 127}, /* page  2 */
                                      { 31,  63,  63,  63,  63}, /* page  3 */
                                      { 31,  63,  63,  63,  95}, /* page  4 */
                                      { 31,  63,  63,  63,  47}, /* page  5 */
                                      { 31,  63,  63,  31,  95}, /* page  6 */
                                      { 31,  63,  63,  31,  47}, /* page  7 */
                                      { 31,  63,  31,  31,  95}, /* page  8 */
                                      { 31,  63,  31,  31,  47}, /* page  9 */
                                      { 31,  31,  31,  31,  95}, /* page 10 */
                                      { 31,  31,  31,  31,  47}, /* page 11 */
                                      { 31,  31,  31,  31,  91}, /* page 12 */
                                      { 31,  31,  31,  15,  47}, /* page 13 */
                                      { 31,  31,  31,  15,  91}, /* page 14 */
                                      { 31,  31,  15,  15,  47}, /* page 15 */
                                      { 31,  31,  15,  15,  94}, /* page 16 */
                                      { 31,  15,  15,  15,  47}, /* page 17 */
                                      { 31,  15,  15,  15,  94}, /* page 18 */
                                      { 15,  15,  15,  15,  47}, /* page 19 */
                                      { 15,  15,  15,  15,  91}, /* page 20 */
                                      { 15,  15,  15,  15,  39}, /* page 21 */
                                      { 15,  15,  15,  14,  94}, /* page 22 */
                                      { 15,  15,  15,  14,  39}, /* page 23 */
                                      { 15,  15,  14,  14,  94}, /* page 24 */
                                      { 15,  14,  14,  14,  39}, /* page 25 */
                                      { 15,  14,  14,  14,  94}, /* page 26 */
                                      { 14,  14,  14,  14,  39}, /* page 27 */
                                      { 14,  14,  14,  14,  94}, /* page 28 */
                                      { 14,  14,  14,  14,  39}, /* page 29 */
                                      { 14,  14,  14,   6,  90}, /* page 30 */
                                      { 14,  14,  14,   6,  39}, /* page 31 */
                                      { 14,  14,  14,   6,  90}, /* page 32 */
                                      { 14,  14,   6,   6,  39}, /* page 33 */
                                      { 14,   6,   6,   6,  90}, /* page 34 */
                                      { 14,   6,   6,   6,  39}, /* page 35 */
                                      {  6,   6,   6,   6,  90}, /* page 36 */
                                      {  6,   6,   6,   6,  39}, /* page 37 */
                                      {  6,   6,   6,   6,  90}, /* page 38 */
                                      {  6,   6,   6,   6,  37}, /* page 39 */
                                      {  6,   6,   6,   2,  90}, /* page 40 */
                                      {  6,   6,   2,   2,  37}, /* page 41 */
                                      {  6,   6,   2,   2,  90}, /* page 42 */
                                      {  6,   2,   2,   2,  37}, /* page 43 */
                                      {  6,   2,   2,   2,  90}, /* page 44 */
                                      {  2,   2,   2,   2,  37}, /* page 45 */
                                      {  2,   2,   2,   2,  90}, /* page 46 */
                                      {  0,   2,   2,   2,  37}, /* page 47 */
                                      {  0,   2,   2,   2,  90}, /* page 48 */
                                      {  0,   0,   2,   2,  37}, /* page 49 */
                                      {  0,   0,   0,   2,  90}, /* page 50 */
                                      {  0,   0,   0,   2,  37}, /* page 51 */
                                      {  0,   0,   0,   2,  90}, /* page 52 */
                                      {  0,   0,   0,   0,  37}, /* page 53 */
                                      {  0,   0,   0,   0,  90}, /* page 54 */
                                      {  0,   0,   0,   0,  37}, /* page 55 */
                                      {  0,   0,   0,   0,  88}, /* page 56 */
                                      {  0,   0,   0,   0,  33}, /* page 57 */
                                      {  0,   0,   0,   0,  80}, /* page 58 */
                                      {  0,   0,   0,   0,  32}, /* page 59 */
                                      {  0,   0,   0,   0,  64}, /* page 60 */
                                      {  0,   0,   0,   0,   0}  /* page 61 */
                                      };

const unsigned char disp3_hf[61][5] = {
                                      {127,  63,  63,  63,  31}, /* page  1 */
                                      { 63,  63,  63,  63,  31}, /* page  2 */
                                      { 95,  63,  63,  63,  31}, /* page  3 */
                                      { 47,  63,  63,  63,  31}, /* page  4 */
                                      { 95,  31,  63,  63,  31}, /* page  5 */
                                      { 47,  31,  63,  63,  31}, /* page  6 */
                                      { 95,  31,  31,  63,  31}, /* page  7 */
                                      { 47,  31,  31,  63,  31}, /* page  8 */
                                      { 95,  31,  31,  31,  31}, /* page  9 */
                                      { 47,  31,  31,  31,  31}, /* page 10 */
                                      { 94,  31,  31,  31,  31}, /* page 11 */
                                      { 47,  15,  31,  31,  31}, /* page 12 */
                                      { 94,  15,  31,  31,  31}, /* page 13 */
                                      { 47,  15,  15,  31,  31}, /* page 14 */
                                      { 94,  15,  15,  31,  31}, /* page 15 */
                                      { 47,  15,  15,  15,  31}, /* page 16 */
                                      { 94,  15,  15,  15,  31}, /* page 17 */
                                      { 47,  15,  15,  15,  15}, /* page 18 */
                                      { 94,  15,  15,  15,  15}, /* page 19 */
                                      { 39,  15,  15,  15,  15}, /* page 20 */
                                      { 94,  14,  15,  15,  15}, /* page 21 */
                                      { 39,  14,  15,  15,  15}, /* page 22 */
                                      { 94,  14,  14,  15,  15}, /* page 23 */
                                      { 39,  14,  14,  15,  15}, /* page 24 */
                                      { 94,  14,  14,  15,  15}, /* page 25 */
                                      { 39,  14,  14,  14,  15}, /* page 26 */
                                      { 94,  14,  14,  15,  15}, /* page 27 */
                                      { 39,  14,  14,  14,  14}, /* page 28 */
                                      { 90,  14,  14,  14,  14}, /* page 29 */
                                      { 39,  14,  14,  14,  14}, /* page 30 */
                                      { 90,   6,  14,  14,  14}, /* page 31 */
                                      { 39,   6,   6,  14,  14}, /* page 32 */
                                      { 90,   6,   6,  14,  14}, /* page 33 */
                                      { 39,   6,   6,  14,  14}, /* page 34 */
                                      { 90,   6,   6,   6,  14}, /* page 35 */
                                      { 39,   6,   6,   6,  14}, /* page 36 */
                                      { 90,   6,   6,   6,   6}, /* page 37 */
                                      { 37,   6,   6,   6,   6}, /* page 38 */
                                      { 90,   2,   6,   6,   6}, /* page 39 */
                                      { 37,   2,   6,   6,   6}, /* page 40 */
                                      { 90,   2,   6,   6,   6}, /* page 41 */
                                      { 37,   2,   2,   6,   6}, /* page 42 */
                                      { 90,   2,   2,   6,   6}, /* page 43 */
                                      { 37,   2,   2,   2,   6}, /* page 44 */
                                      { 90,   2,   2,   2,   6}, /* page 45 */
                                      { 37,   2,   2,   2,   2}, /* page 46 */
                                      { 90,   2,   2,   2,   2}, /* page 47 */
                                      { 37,   2,   2,   2,   0}, /* page 48 */
                                      { 90,   2,   2,   2,   0}, /* page 49 */
                                      { 37,   2,   2,   0,   0}, /* page 50 */
                                      { 90,   2,   2,   0,   0}, /* page 51 */
                                      { 37,   2,   0,   0,   0}, /* page 52 */
                                      { 90,   2,   0,   0,   0}, /* page 53 */
                                      { 37,   0,   0,   0,   0}, /* page 54 */
                                      { 88,   0,   0,   0,   0}, /* page 55 */
                                      { 33,   0,   0,   0,   0}, /* page 56 */
                                      { 80,   0,   0,   0,   0}, /* page 57 */
                                      { 32,   0,   0,   0,   0}, /* page 58 */
                                      { 64,   0,   0,   0,   0}, /* page 59 */
                                      {  0,   0,   0,   0,   0}, /* page 60 */
                                      {  0,   0,   0,   0,   0}  /* page 61 */
                                      };

const unsigned char disp2_up[62][5] = {
                                      {  0,   0,   0,   0,   0}, /* page  1 */
                                      {  0,   0,   0,   0,   2}, /* page  2 */
                                      {  0,   0,   0,   0,   2}, /* page  3 */
                                      {  0,   0,   0,   0,  10}, /* page  4 */
                                      {  0,   0,   0,   0,  10}, /* page  5 */
                                      {  0,   0,   0,   0,  26}, /* page  6 */
                                      {  0,   0,   0,   0,  26}, /* page  7 */
                                      {  0,   0,   0,   0,  90}, /* page  8 */
                                      {  0,   0,   0,   0,  90}, /* page  9 */
                                      {  0,   0,   0,   0, 101}, /* page 10 */
                                      {  0,   0,   0,  64, 124}, /* page 11 */
                                      {  0,   0,   0,  64, 101}, /* page 12 */
                                      {  0,   0,  64,  64, 122}, /* page 13 */
                                      {  0,   0,  64,  64, 101}, /* page 14 */
                                      {  0,  64,  64,  64, 122}, /* page 15 */
                                      {  0,  64,  64,  64, 101}, /* page 16 */
                                      { 64,  64,  64,  64, 122}, /* page 17 */
                                      { 64,  64,  64,  64, 101}, /* page 18 */
                                      { 64,  64,  64,  96, 122}, /* page 19 */
                                      { 64,  64,  64,  96, 101}, /* page 20 */
                                      { 64,  64,  96,  96, 122}, /* page 21 */
                                      { 64,  64,  96,  96, 101}, /* page 22 */
                                      { 64,  96,  96,  96, 122}, /* page 23 */
                                      { 64,  96,  96,  96, 101}, /* page 24 */
                                      { 96,  96,  96,  96, 122}, /* page 25 */
                                      { 96,  96,  96,  96, 101}, /* page 26 */
                                      { 96,  96,  96,  96, 122}, /* page 27 */
                                      { 96,  96,  96, 112, 117}, /* page 28 */
                                      { 96,  96,  96, 112, 122}, /* page 29 */
                                      { 96,  96, 112, 112, 117}, /* page 30 */
                                      { 96,  96, 112, 112, 122}, /* page 31 */
                                      { 96, 112, 112, 112, 117}, /* page 32 */
                                      { 96, 112, 112, 112, 122}, /* page 33 */
                                      {112, 112, 112, 112, 117}, /* page 34 */
                                      {112, 112, 112, 112, 122}, /* page 35 */
                                      {112, 112, 112, 112, 117}, /* page 36 */
                                      {112, 112, 112, 113, 123}, /* page 37 */
                                      {112, 112, 112, 113, 117}, /* page 38 */
                                      {112, 112, 113, 113, 123}, /* page 39 */
                                      {112, 112, 113, 113, 117}, /* page 40 */
                                      {112, 113, 113, 113, 123}, /* page 41 */
                                      {112, 113, 113, 113, 117}, /* page 42 */
                                      {113, 113, 113, 113, 123}, /* page 43 */
                                      {113, 113, 113, 113, 117}, /* page 44 */
                                      {113, 113, 113, 113, 123}, /* page 45 */
                                      {113, 113, 113, 121, 125}, /* page 46 */
                                      {113, 113, 113, 121, 123}, /* page 47 */
                                      {113, 113, 121, 121, 125}, /* page 48 */
                                      {113, 113, 121, 121, 123}, /* page 49 */
                                      {113, 121, 121, 121, 125}, /* page 50 */
                                      {113, 121, 121, 121, 123}, /* page 51 */
                                      {121, 121, 121, 121, 125}, /* page 52 */
                                      {121, 121, 121, 121, 123}, /* page 53 */
                                      {121, 121, 121, 121, 125}, /* page 54 */
                                      {121, 121, 121, 125, 127}, /* page 55 */
                                      {121, 121, 121, 125, 127}, /* page 56 */
                                      {121, 121, 125, 125, 127}, /* page 57 */
                                      {121, 121, 125, 125, 125}, /* page 58 */
                                      {121, 125, 125, 125, 127}, /* page 59 */
                                      {121, 125, 125, 125, 125}, /* page 60 */
                                      {121, 125, 125, 125, 127}, /* page 61 */
                                      {  0,   0,   0,   0, 127}  /* page 62, horizontal line */
                                      };

const unsigned char disp2_hf[61][5] = {
                                      {  0,   0,   0,   0,   0}, /* page  1 */
                                      {  0,   0,   0,   0,   2}, /* page  2 */
                                      {  0,   0,   0,   0,   2}, /* page  3 */
                                      {  0,   0,   0,   4,   2}, /* page  4 */
                                      {  0,   0,   0,   4,   2}, /* page  5 */
                                      {  0,   0,   4,   4,   2}, /* page  6 */
                                      {  0,   0,   4,   4,   2}, /* page  7 */
                                      {  0,   4,   4,   4,   2}, /* page  8 */
                                      {  0,   4,   4,   4,   2}, /* page  9 */
                                      {  8,   4,   4,   4,   2}, /* page 10 */
                                      {  8,   4,   4,   4,   2}, /* page 11 */
                                      {  8,   4,   4,   4,   6}, /* page 12 */
                                      {  8,   4,   4,   4,   6}, /* page 13 */
                                      {  8,  12,   4,   4,   6}, /* page 14 */
                                      {  8,  12,   4,   4,   6}, /* page 15 */
                                      {  9,  12,   4,   4,   6}, /* page 16 */
                                      {  9,  12,   4,   4,   6}, /* page 17 */
                                      {  9,  12,  12,   4,   6}, /* page 18 */
                                      {  9,  12,  12,   4,   6}, /* page 19 */
                                      {  9,  13,  12,   4,   6}, /* page 20 */
                                      {  9,  13,  12,   4,   6}, /* page 21 */
                                      {  9,  13,  12,   4,   6}, /* page 22 */
                                      {  9,  13,  12,  12,   6}, /* page 23 */
                                      {  9,  13,  13,  12,   6}, /* page 24 */
                                      {  9,  13,  13,  12,   6}, /* page 25 */
                                      {  9,  13,  13,  12,   6}, /* page 26 */
                                      { 25,  13,  13,  12,   6}, /* page 27 */
                                      { 25,  13,  13,  12,   6}, /* page 28 */
                                      { 25,  13,  13,  12,  14}, /* page 29 */
                                      { 25,  13,  13,  12,  14}, /* page 30 */
                                      { 25,  29,  13,  12,  14}, /* page 31 */
                                      { 25,  29,  13,  13,  14}, /* page 32 */
                                      { 25,  29,  13,  13,  14}, /* page 33 */
                                      { 57,  29,  13,  13,  14}, /* page 34 */
                                      { 57,  29,  13,  13,  14}, /* page 35 */
                                      { 57,  29,  13,  13,  14}, /* page 36 */
                                      { 57,  29,  29,  13,  14}, /* page 37 */
                                      { 57,  61,  29,  13,  14}, /* page 38 */
                                      { 57,  61,  29,  13,  14}, /* page 39 */
                                      { 57,  61,  29,  13,  14}, /* page 40 */
                                      {121,  61,  29,  13,  14}, /* page 41 */
                                      {121, 125,  29,  13,  14}, /* page 42 */
                                      {121, 125,  29,  13,  14}, /* page 43 */
                                      {121, 125,  61,  13,  14}, /* page 44 */
                                      {121, 125,  61,  13,  14}, /* page 45 */
                                      {121, 125,  61,  13,  14}, /* page 46 */
                                      {121, 125,  61,  29,  14}, /* page 47 */
                                      {121, 125,  61,  29,  15}, /* page 48 */
                                      {121, 125,  61,  29,  15}, /* page 49 */
                                      {121, 125, 125,  29,  15}, /* page 50 */
                                      {121, 125, 125,  29,  15}, /* page 51 */
                                      {121, 125, 125,  29,  15}, /* page 52 */
                                      {121, 125, 125,  61,  15}, /* page 53 */
                                      {121, 125, 125,  61,  15}, /* page 54 */
                                      {121, 125, 125,  61,  31}, /* page 55 */
                                      {121, 125, 125, 125,  31}, /* page 56 */
                                      {121, 125, 125, 125,  31}, /* page 57 */
                                      {121, 125, 125, 125,  63}, /* page 58 */
                                      {121, 125, 125, 125,  63}, /* page 59 */
                                      {121, 125, 125, 125, 127}, /* page 60 */
                                      {121, 125, 125, 125, 127}  /* page 61 */
                                      };

const unsigned char disp4_up[62][5] = {
                                      {  0,   0,   0,   0,   0}, /* page  1 */
                                      {  0,   0,   0,   0,   0}, /* page  2 */
                                      {  4,   0,   0,   0,   0}, /* page  3 */
                                      {  4,   0,   0,   0,   0}, /* page  4 */
                                      {  5,   0,   0,   0,   0}, /* page  5 */
                                      {  5,   0,   0,   0,   0}, /* page  6 */
                                      { 37,   0,   0,   0,   0}, /* page  7 */
                                      { 37,   0,   0,   0,   0}, /* page  8 */
                                      {101,   0,   0,   0,   0}, /* page  9 */
                                      {122,   0,   0,   0,   0}, /* page 10 */
                                      { 99,   0,   0,   0,   0}, /* page 11 */
                                      {122,  64,   0,   0,   0}, /* page 12 */
                                      {101,  64,   0,   0,   0}, /* page 13 */
                                      {122,  64,  64,   0,   0}, /* page 14 */
                                      {101,  64,  64,   0,   0}, /* page 15 */
                                      {122,  64,  64,  64,   0}, /* page 16 */
                                      {101,  64,  64,  64,   0}, /* page 17 */
                                      {122,  64,  64,  64,  64}, /* page 18 */
                                      {101,  64,  64,  64,  64}, /* page 19 */
                                      {122,  96,  64,  64,  64}, /* page 20 */
                                      {101,  96,  64,  64,  64}, /* page 21 */
                                      {122,  96,  96,  64,  64}, /* page 22 */
                                      {101,  96,  96,  64,  64}, /* page 23 */
                                      {122,  96,  96,  96,  64}, /* page 24 */
                                      {101,  96,  96,  96,  64}, /* page 25 */
                                      {122,  96,  96,  96,  96}, /* page 26 */
                                      {117,  96,  96,  96,  96}, /* page 27 */
                                      {122,  96,  96,  96,  96}, /* page 28 */
                                      {117, 112,  96,  96,  96}, /* page 29 */
                                      {122, 112,  96,  96,  96}, /* page 30 */
                                      {117, 112, 112,  96,  96}, /* page 31 */
                                      {122, 112, 112,  96,  96}, /* page 32 */
                                      {117, 112, 112, 112,  96}, /* page 33 */
                                      {122, 112, 112, 112,  96}, /* page 34 */
                                      {117, 112, 112, 112, 112}, /* page 35 */
                                      {123, 112, 112, 112, 112}, /* page 36 */
                                      {117, 112, 112, 112, 112}, /* page 37 */
                                      {123, 113, 112, 112, 112}, /* page 38 */
                                      {117, 113, 112, 112, 112}, /* page 39 */
                                      {123, 113, 113, 112, 112}, /* page 40 */
                                      {117, 113, 113, 112, 112}, /* page 41 */
                                      {123, 113, 113, 113, 112}, /* page 42 */
                                      {117, 113, 113, 113, 112}, /* page 43 */
                                      {123, 113, 113, 113, 113}, /* page 44 */
                                      {125, 113, 113, 113, 113}, /* page 45 */
                                      {123, 113, 113, 113, 113}, /* page 46 */
                                      {125, 121, 113, 113, 113}, /* page 47 */
                                      {123, 121, 113, 113, 113}, /* page 48 */
                                      {125, 121, 121, 113, 113}, /* page 49 */
                                      {123, 121, 121, 113, 113}, /* page 50 */
                                      {125, 121, 121, 121, 113}, /* page 51 */
                                      {123, 121, 121, 121, 113}, /* page 52 */
                                      {125, 121, 121, 121, 121}, /* page 53 */
                                      {127, 121, 121, 121, 121}, /* page 54 */
                                      {125, 121, 121, 121, 121}, /* page 55 */
                                      {127, 125, 121, 121, 121}, /* page 56 */
                                      {125, 125, 121, 121, 121}, /* page 57 */
                                      {127, 125, 125, 121, 121}, /* page 58 */
                                      {125, 125, 125, 121, 121}, /* page 59 */
                                      {127, 125, 125, 125, 121}, /* page 60 */
                                      {127, 125, 125, 125, 121}, /* page 61 */
                                      {127,   0,   0,   0,   0}  /* page 62, horizontal line */
                                      };

const unsigned char disp4_hf[61][5] = {
                                      {  0,   0,   0,   0,   0}, /* page  1 */
                                      {  0,   0,   0,   0,   0}, /* page  2 */
                                      {  2,   0,   0,   0,   0}, /* page  3 */
                                      {  2,   0,   0,   0,   0}, /* page  4 */
                                      {  2,   4,   0,   0,   0}, /* page  5 */
                                      {  2,   4,   0,   0,   0}, /* page  6 */
                                      {  2,   4,   4,   0,   0}, /* page  7 */
                                      {  2,   4,   4,   0,   0}, /* page  8 */
                                      {  2,   4,   4,   4,   0}, /* page  9 */
                                      {  2,   4,   4,   4,   0}, /* page 10 */
                                      {  2,   4,   4,   4,   8}, /* page 11 */
                                      {  2,   4,   4,   4,   8}, /* page 12 */
                                      {  6,   4,   4,   4,   8}, /* page 13 */
                                      {  6,   4,   4,   4,   8}, /* page 14 */
                                      {  6,   4,   4,  12,   8}, /* page 15 */
                                      {  6,   4,   4,  12,   8}, /* page 16 */
                                      {  6,   4,   4,  12,   9}, /* page 17 */
                                      {  6,   4,   4,  12,   9}, /* page 18 */
                                      {  6,   4,  12,  12,   9}, /* page 19 */
                                      {  6,   4,  12,  12,   9}, /* page 20 */
                                      {  6,   4,  12,  13,   9}, /* page 21 */
                                      {  6,  12,  12,  13,   9}, /* page 22 */
                                      {  6,  12,  12,  13,   9}, /* page 23 */
                                      {  6,  12,  12,  13,   9}, /* page 24 */
                                      {  6,  12,  13,  13,   9}, /* page 25 */
                                      {  6,  12,  13,  13,  25}, /* page 26 */
                                      {  6,  12,  13,  13,  25}, /* page 27 */
                                      { 14,  12,  13,  13,  25}, /* page 28 */
                                      { 14,  12,  13,  13,  25}, /* page 29 */
                                      { 14,  12,  13,  29,  25}, /* page 30 */
                                      { 14,  12,  13,  29,  25}, /* page 31 */
                                      { 14,  12,  13,  29,  25}, /* page 32 */
                                      { 14,  13,  13,  29,  25}, /* page 33 */
                                      { 14,  13,  13,  29,  25}, /* page 34 */
                                      { 14,  13,  13,  29,  57}, /* page 35 */
                                      { 14,  13,  13,  29,  57}, /* page 36 */
                                      { 14,  13,  29,  29,  57}, /* page 37 */
                                      { 14,  13,  29,  29,  57}, /* page 38 */
                                      { 14,  13,  29,  61,  57}, /* page 39 */
                                      { 14,  13,  29,  61, 121}, /* page 40 */
                                      { 14,  13,  29,  61, 121}, /* page 41 */
                                      { 14,  13,  29,  61, 121}, /* page 42 */
                                      { 14,  13,  29, 125, 121}, /* page 43 */
                                      { 14,  13,  29, 125, 121}, /* page 44 */
                                      { 14,  13,  61, 125, 121}, /* page 45 */
                                      { 14,  29,  61, 125, 121}, /* page 46 */
                                      { 14,  29,  61, 125, 121}, /* page 47 */
                                      { 14,  29,  61, 125, 121}, /* page 48 */
                                      { 15,  29,  61, 125, 121}, /* page 49 */
                                      { 15,  29,  61, 125, 121}, /* page 50 */
                                      { 15,  29, 125, 125, 121}, /* page 51 */
                                      { 15,  61, 125, 125, 121}, /* page 52 */
                                      { 15,  61, 125, 125, 121}, /* page 53 */
                                      { 31,  61, 125, 125, 121}, /* page 54 */
                                      { 31,  61, 125, 125, 121}, /* page 55 */
                                      { 31,  61, 125, 125, 121}, /* page 56 */
                                      { 31, 125, 125, 125, 121}, /* page 57 */
                                      { 31, 125, 125, 125, 121}, /* page 58 */
                                      { 63, 125, 125, 125, 121}, /* page 59 */
                                      { 63, 125, 125, 125, 121}, /* page 60 */
                                      {127, 125, 125, 125, 121}  /* page 61 */
                                      };

/* ######################################################################## */

/* Constant Definitions for the Sanduhr-digits showing the numbers */
/* First dimension of the Array is the digit number (10), second one */
/* is the number of columns (5) */
const unsigned char col_digit_upright[10][5] = {
                                                 {  0,   61,  66,  66,  61}, /* 0 */
                                                 {  0,    0,   8,   4, 127}, /* 1 */
                                                 {  0,  100,  82,  67,  76}, /* 2 */
                                                 {  0,   36,  67,  67,  60}, /* 3 */
                                                 {  0,    9,   5, 123,   3}, /* 4 */
                                                 {  0,   47,  74,  74,  51}, /* 5 */
                                                 {  0,   61,  67,  67,  52}, /* 6 */
                                                 {  0,    2, 114,  11,   6}, /* 7 */
                                                 {  0,   60,  67,  67,  60}, /* 8 */
                                                 {  0,   44,  67,  67,  60}  /* 9 */
                                               };

const unsigned char col_digit_headfrst[10][5] = {
                                                  { 61,  66,  66,  61,  0}, /* 0 */
                                                  {127,  32,  16,   0,  0}, /* 1 */
                                                  { 50,  67,  74,  38,  0}, /* 2 */
                                                  { 60,  67,  67,  37,  0}, /* 3 */
                                                  { 65,  95,  33,  17,  0}, /* 4 */
                                                  { 77,  82,  82, 117,  0}, /* 5 */
                                                  { 44,  67,  67,  61,  0}, /* 6 */
                                                  { 96,  81,  78,  64,  0}, /* 7 */
                                                  { 60,  67,  67,  60,  0}, /* 8 */
                                                  { 60,  67,  67,  52,  0}  /* 9 */
                                                };


/* ######################################################################## */

/*****************************************************************************
Name:      	show_numbers    
Parameters: unsigned char num1
            unsigned char num2                    
            unsigned char mode
Returns:    none
Description: Shows 2 numbers from 0 to 99 on all the displays using
             a fixed font definition
*****************************************************************************/
void f_vd_SHOW_NUMBERS(unsigned char num1, unsigned char num2, unsigned char mode)
{
unsigned char lowDigit1, lowDigit2, highDigit1, highDigit2, data[8];

	if (num1 > 99) {num1 = 99;}
	if (num2 > 99) {num2 = 99;}

	highDigit1 = (unsigned char)(num1 / 10);
	lowDigit1  = (unsigned char)(num1 - (highDigit1*10));
	highDigit2 = (unsigned char)(num2 / 10);
	lowDigit2  = (unsigned char)(num2 - (highDigit2*10));		

	//Column 0	
	data[0] = max7221cmd_sel_col0;                  //Command : Display Column 0 on Disp4
	data[2] = max7221cmd_sel_col0;                  //Command : Display Column 0 on Disp3
	data[4] = max7221cmd_sel_col0;                  //Command : Display Column 0 on Disp2
	data[6] = max7221cmd_sel_col0;                  //Command : Display Column 0 on Disp1
	if (mode == D_4digits_upright_disp)
        {	
	   data[1] = col_digit_upright[lowDigit2][0];   //Data    : Pattern to show on Disp4
	   data[3] = col_digit_upright[lowDigit1][0];   //Data    : Pattern to show on Disp3
	   data[5] = col_digit_upright[highDigit2][0];  //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_upright[highDigit1][0];  //Data    : Pattern to show on Disp1
        }
	else if (mode == D_2digits_upright_disp)
        { 
	   data[1] = 0;                                 //Data    : Pattern to show on Disp4
           data[3] = col_digit_upright[lowDigit1][0];   //Data    : Pattern to show on Disp3
	   data[5] = 0;                                 //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_upright[highDigit1][0];  //Data    : Pattern to show on Disp1
	}
	else if (mode == D_4digits_headfirst_disp)
        {	
	   data[1] = col_digit_headfrst[highDigit1][0]; //Data    : Pattern to show on Disp4
	   data[3] = col_digit_headfrst[highDigit2][0]; //Data    : Pattern to show on Disp3
	   data[5] = col_digit_headfrst[lowDigit1][0];  //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_headfrst[lowDigit2][0];  //Data    : Pattern to show on Disp1
        }
	else if (mode == D_2digits_headfirst_disp)
        { 
	   data[1] = col_digit_headfrst[highDigit1][0]; //Data    : Pattern to show on Disp4
           data[3] = 0;                                 //Data    : Pattern to show on Disp3
	   data[5] = col_digit_headfrst[lowDigit1][0];  //Data    : Pattern to show on Disp2
 	   data[7] = 0;                                 //Data    : Pattern to show on Disp4
	}
	f_vd_4daisyChained_max7221_SPI_tx(data);
	//End of Column 0

	//Column 1	
	data[0] = max7221cmd_sel_col1;                  //Command : Display Column 1 on Disp4
	data[2] = max7221cmd_sel_col1;                  //Command : Display Column 1 on Disp3
	data[4] = max7221cmd_sel_col1;                  //Command : Display Column 1 on Disp2
	data[6] = max7221cmd_sel_col1;                  //Command : Display Column 1 on Disp1
	if (mode == D_4digits_upright_disp)
        {	
	   data[1] = col_digit_upright[lowDigit2][1];   //Data    : Pattern to show on Disp4
	   data[3] = col_digit_upright[lowDigit1][1];   //Data    : Pattern to show on Disp3
	   data[5] = col_digit_upright[highDigit2][1];  //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_upright[highDigit1][1];  //Data    : Pattern to show on Disp1
        }
	else if (mode == D_2digits_upright_disp)
        { 
	   data[1] = 0;                                 //Data    : Pattern to show on Disp4
           data[3] = col_digit_upright[lowDigit1][1];   //Data    : Pattern to show on Disp3
	   data[5] = 0;                                 //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_upright[highDigit1][1];  //Data    : Pattern to show on Disp1
	}
	else if (mode == D_4digits_headfirst_disp)
        {	
	   data[1] = col_digit_headfrst[highDigit1][1]; //Data    : Pattern to show on Disp4
	   data[3] = col_digit_headfrst[highDigit2][1]; //Data    : Pattern to show on Disp3
	   data[5] = col_digit_headfrst[lowDigit1][1];  //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_headfrst[lowDigit2][1];  //Data    : Pattern to show on Disp1
        }
	else if (mode == D_2digits_headfirst_disp)
        { 
	   data[1] = col_digit_headfrst[highDigit1][1]; //Data    : Pattern to show on Disp4
           data[3] = 0;                                 //Data    : Pattern to show on Disp3
	   data[5] = col_digit_headfrst[lowDigit1][1];  //Data    : Pattern to show on Disp2
 	   data[7] = 0;                                 //Data    : Pattern to show on Disp4
	}
	f_vd_4daisyChained_max7221_SPI_tx(data);
	//End of Column 1

	//Column 2	
	data[0] = max7221cmd_sel_col2;                  //Command : Display Column 2 on Disp4
	data[2] = max7221cmd_sel_col2;                  //Command : Display Column 2 on Disp3
	data[4] = max7221cmd_sel_col2;                  //Command : Display Column 2 on Disp2
	data[6] = max7221cmd_sel_col2;                  //Command : Display Column 2 on Disp1
	if (mode == D_4digits_upright_disp)
        {	
	   data[1] = col_digit_upright[lowDigit2][2];   //Data    : Pattern to show on Disp4
	   data[3] = col_digit_upright[lowDigit1][2];   //Data    : Pattern to show on Disp3
	   data[5] = col_digit_upright[highDigit2][2];  //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_upright[highDigit1][2];  //Data    : Pattern to show on Disp1
        }
	else if (mode == D_2digits_upright_disp)
        { 
	   data[1] = 0;                                 //Data    : Pattern to show on Disp4
           data[3] = col_digit_upright[lowDigit1][2];   //Data    : Pattern to show on Disp3
	   data[5] = 0;                                 //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_upright[highDigit1][2];  //Data    : Pattern to show on Disp1
	}
	else if (mode == D_4digits_headfirst_disp)
        {	
	   data[1] = col_digit_headfrst[highDigit1][2]; //Data    : Pattern to show on Disp4
	   data[3] = col_digit_headfrst[highDigit2][2]; //Data    : Pattern to show on Disp3
	   data[5] = col_digit_headfrst[lowDigit1][2];  //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_headfrst[lowDigit2][2];  //Data    : Pattern to show on Disp1
        }
	else if (mode == D_2digits_headfirst_disp)
        { 
	   data[1] = col_digit_headfrst[highDigit1][2]; //Data    : Pattern to show on Disp4
           data[3] = 0;                                 //Data    : Pattern to show on Disp3
	   data[5] = col_digit_headfrst[lowDigit1][2];  //Data    : Pattern to show on Disp2
 	   data[7] = 0;                                 //Data    : Pattern to show on Disp4
	}
	f_vd_4daisyChained_max7221_SPI_tx(data);
	//End of Column 2

	//Column 3	
	data[0] = max7221cmd_sel_col3;                  //Command : Display Column 3 on Disp4
	data[2] = max7221cmd_sel_col3;                  //Command : Display Column 3 on Disp3
	data[4] = max7221cmd_sel_col3;                  //Command : Display Column 3 on Disp2
	data[6] = max7221cmd_sel_col3;                  //Command : Display Column 3 on Disp1
	if (mode == D_4digits_upright_disp)
        {	
	   data[1] = col_digit_upright[lowDigit2][3];   //Data    : Pattern to show on Disp4
	   data[3] = col_digit_upright[lowDigit1][3];   //Data    : Pattern to show on Disp3
	   data[5] = col_digit_upright[highDigit2][3];  //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_upright[highDigit1][3];  //Data    : Pattern to show on Disp1
        }
	else if (mode == D_2digits_upright_disp)
        { 
	   data[1] = 0;                                 //Data    : Pattern to show on Disp4
           data[3] = col_digit_upright[lowDigit1][3];   //Data    : Pattern to show on Disp3
	   data[5] = 0;                                 //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_upright[highDigit1][3];  //Data    : Pattern to show on Disp1
	}
	else if (mode == D_4digits_headfirst_disp)
        {	
	   data[1] = col_digit_headfrst[highDigit1][3]; //Data    : Pattern to show on Disp4
	   data[3] = col_digit_headfrst[highDigit2][3]; //Data    : Pattern to show on Disp3
	   data[5] = col_digit_headfrst[lowDigit1][3];  //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_headfrst[lowDigit2][3];  //Data    : Pattern to show on Disp1
        }
	else if (mode == D_2digits_headfirst_disp)
        { 
	   data[1] = col_digit_headfrst[highDigit1][3]; //Data    : Pattern to show on Disp4
           data[3] = 0;                                 //Data    : Pattern to show on Disp3
	   data[5] = col_digit_headfrst[lowDigit1][3];  //Data    : Pattern to show on Disp2
 	   data[7] = 0;                                 //Data    : Pattern to show on Disp4
	}
	f_vd_4daisyChained_max7221_SPI_tx(data);
	//End of Column 3

	//Column 4	
	data[0] = max7221cmd_sel_col4;                  //Command : Display Column 4 on Disp4
	data[2] = max7221cmd_sel_col4;                  //Command : Display Column 4 on Disp3
	data[4] = max7221cmd_sel_col4;                  //Command : Display Column 4 on Disp2
	data[6] = max7221cmd_sel_col4;                  //Command : Display Column 4 on Disp1
	if (mode == D_4digits_upright_disp)
        {	
	   data[1] = col_digit_upright[lowDigit2][4];   //Data    : Pattern to show on Disp4
	   data[3] = col_digit_upright[lowDigit1][4];   //Data    : Pattern to show on Disp3
	   data[5] = col_digit_upright[highDigit2][4];  //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_upright[highDigit1][4];  //Data    : Pattern to show on Disp1
        }
	else if (mode == D_2digits_upright_disp)
        { 
	   data[1] = 0;                                 //Data    : Pattern to show on Disp4
           data[3] = col_digit_upright[lowDigit1][4];   //Data    : Pattern to show on Disp3
	   data[5] = 0;                                 //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_upright[highDigit1][4];  //Data    : Pattern to show on Disp1
	}
	else if (mode == D_4digits_headfirst_disp)
        {	
	   data[1] = col_digit_headfrst[highDigit1][4]; //Data    : Pattern to show on Disp4
	   data[3] = col_digit_headfrst[highDigit2][4]; //Data    : Pattern to show on Disp3
	   data[5] = col_digit_headfrst[lowDigit1][4];  //Data    : Pattern to show on Disp2
 	   data[7] = col_digit_headfrst[lowDigit2][4];  //Data    : Pattern to show on Disp1
        }
	else if (mode == D_2digits_headfirst_disp)
        { 
	   data[1] = col_digit_headfrst[highDigit1][4]; //Data    : Pattern to show on Disp4
           data[3] = 0;                                 //Data    : Pattern to show on Disp3
	   data[5] = col_digit_headfrst[lowDigit1][4];  //Data    : Pattern to show on Disp2
 	   data[7] = 0;                                 //Data    : Pattern to show on Disp4
	}
	f_vd_4daisyChained_max7221_SPI_tx(data);
	//End of Column 4
}


/*****************************************************************************
Name:      	show_sanduhr_page    
Parameters: unsigned char page
            unsigned char mode                    
Returns:    none
Description: Shows one selectable page out of 62 fixed defined ones
*****************************************************************************/
void f_vd_SHOW_SANDUHR_PAGE(unsigned char page, unsigned char mode)
{
unsigned char data[8];

   if (page > 61) {page = 61;}
   if ( (page == 61) && (mode == D_headfirst_sand_disp) ) {mode = D_upright_sand_disp;}

	data[0] = max7221cmd_sel_col0;            //Command : Display Column 0 on Disp4
	data[2] = max7221cmd_sel_col0;            //Command : Display Column 0 on Disp3
	data[4] = max7221cmd_sel_col0;            //Command : Display Column 0 on Disp2
	data[6] = max7221cmd_sel_col0;            //Command : Display Column 0 on Disp1
        if (mode == D_upright_sand_disp)
        {
	   data[1] = disp4_up[page][0];           //Data    : Pattern to show in upright position
	   data[3] = disp3_up[page][0];
	   data[5] = disp2_up[page][0];
	   data[7] = disp1_up[page][0];
        }
        else if (mode == D_headfirst_sand_disp)
        {
	   data[1] = disp4_hf[page][0];           //Data    : Pattern to show in headfirst position
	   data[3] = disp3_hf[page][0];
	   data[5] = disp2_hf[page][0];
	   data[7] = disp1_hf[page][0];
        }
	f_vd_4daisyChained_max7221_SPI_tx(data);

	data[0] = max7221cmd_sel_col1;            //Command : Display Column 1 on Disp4
	data[2] = max7221cmd_sel_col1;            //Command : Display Column 1 on Disp3
	data[4] = max7221cmd_sel_col1;            //Command : Display Column 1 on Disp2
	data[6] = max7221cmd_sel_col1;            //Command : Display Column 1 on Disp1
        if (mode == D_upright_sand_disp)
        {
	   data[1] = disp4_up[page][1];           //Data    : Pattern to show in upright position
	   data[3] = disp3_up[page][1];
	   data[5] = disp2_up[page][1];
	   data[7] = disp1_up[page][1];
        }
        else if (mode == D_headfirst_sand_disp)
        {
	   data[1] = disp4_hf[page][1];           //Data    : Pattern to show in headfirst position
	   data[3] = disp3_hf[page][1];
	   data[5] = disp2_hf[page][1];
	   data[7] = disp1_hf[page][1];
        }
	f_vd_4daisyChained_max7221_SPI_tx(data);

	data[0] = max7221cmd_sel_col2;            //Command : Display Column 2 on Disp4
	data[2] = max7221cmd_sel_col2;            //Command : Display Column 2 on Disp3
	data[4] = max7221cmd_sel_col2;            //Command : Display Column 2 on Disp2
	data[6] = max7221cmd_sel_col2;            //Command : Display Column 2 on Disp1
        if (mode == D_upright_sand_disp)
        {
	   data[1] = disp4_up[page][2];           //Data    : Pattern to show in upright position
	   data[3] = disp3_up[page][2];
	   data[5] = disp2_up[page][2];
	   data[7] = disp1_up[page][2];
        }
        else if (mode == D_headfirst_sand_disp)
        {
	   data[1] = disp4_hf[page][2];           //Data    : Pattern to show in headfirst position
	   data[3] = disp3_hf[page][2];
	   data[5] = disp2_hf[page][2];
	   data[7] = disp1_hf[page][2];
        }
	f_vd_4daisyChained_max7221_SPI_tx(data);

	data[0] = max7221cmd_sel_col3;            //Command : Display Column 3 on Disp4
	data[2] = max7221cmd_sel_col3;            //Command : Display Column 3 on Disp3
	data[4] = max7221cmd_sel_col3;            //Command : Display Column 3 on Disp2
	data[6] = max7221cmd_sel_col3;            //Command : Display Column 3 on Disp1
        if (mode == D_upright_sand_disp)
        {
	   data[1] = disp4_up[page][3];           //Data    : Pattern to show in upright position
	   data[3] = disp3_up[page][3];
	   data[5] = disp2_up[page][3];
	   data[7] = disp1_up[page][3];
        }
        else if (mode == D_headfirst_sand_disp)
        {
	   data[1] = disp4_hf[page][3];           //Data    : Pattern to show in headfirst position
	   data[3] = disp3_hf[page][3];
	   data[5] = disp2_hf[page][3];
	   data[7] = disp1_hf[page][3];
        }
	f_vd_4daisyChained_max7221_SPI_tx(data);

	data[0] = max7221cmd_sel_col4;            //Command : Display Column 4 on Disp4
	data[2] = max7221cmd_sel_col4;            //Command : Display Column 4 on Disp3
	data[4] = max7221cmd_sel_col4;            //Command : Display Column 4 on Disp2
	data[6] = max7221cmd_sel_col4;            //Command : Display Column 4 on Disp1
        if (mode == D_upright_sand_disp)
        {
	   data[1] = disp4_up[page][4];           //Data    : Pattern to show in upright position
	   data[3] = disp3_up[page][4];
	   data[5] = disp2_up[page][4];
	   data[7] = disp1_up[page][4];
        }
        else if (mode == D_headfirst_sand_disp)
        {
	   data[1] = disp4_hf[page][4];           //Data    : Pattern to show in headfirst position
	   data[3] = disp3_hf[page][4];
	   data[5] = disp2_hf[page][4];
	   data[7] = disp1_hf[page][4];
        }
	f_vd_4daisyChained_max7221_SPI_tx(data);
}
