/************************************************************************************
*                                                                                   *
*   File Name   : max7221.c                                                         *
*   Contents    : Low-Level-Driver-routines for MAX7221 single and 4 daisy chained  *
*   Version     : 1.4                                                               *
*************************************************************************************/ 
#include "max7221.h"
#include "globals.h"

/*****************************************************************************
Name:      	f_vd_init_max7221_SPI    
Parameters: none                    
Returns:    none
Description: Initialize SPI interface - UART0 in SPI Mode
*****************************************************************************/
void f_vd_init_max7221_SPI(void)
{
  
  	/* initialize chip select port */
  	max7221_spi_cs_dir = 1;	// Change CHIP_SELECT port to output
  	max7221_spi_cs = 1;		// Bring CHIP_SELECT high

  	/* configure UART2 for SPI */
    p1     = p1 | 0x50;     /* TxD0, CLK0 port off */   
    pd1    = pd1 | 0x50;    /* TxD0, CLK0 direction = output */   
    pd1    = pd1 & 0xDF;    /* RxD0 direction = input */
  	u0mr   = 0x01;		/* synchronous mode, internal clock */
  	u0c0   = 0x81;		/* f8 is selected */
                                /* data present in transmit register */
                                /* TxD0 pin is CMOS-output */
                                /* MSB first */
                                /* CKPOL=0 */
    u0rrm  = 0;                 /* Continous receive mode disabled */
  	u0brg  = 80-1;               /* Set baud rate : 1 CLK = 8us */
  	u0c1   = 0x00;		        /* no data reverse, rx & tx disabled */
	te_u0c1 = 1;	            /* Enable tx */
    re_u0c1 = 1;		        /* Enable rx */
}

/*****************************************************************************
Name:      	f_vd_max7221_SPI_tx     
Parameters: 1 Byte data to send
Returns:    1 Byte data received (lowbyte), 1 Byte rx_status (highbyte)
Description: Sends 1 byte data and returns data and status 
*****************************************************************************/
void f_vd_max7221_SPI_tx(unsigned char data)
{
	u0tbl = data;			/* copy data to output register */
	ti_u0c1 = 0;
	while( !ti_u0c1 );		/* Wait for tx to be completed */
	while( !txept_u0c0 );
}
/*****************************************************************************
Name:      	f_vd_4daisyChained_max7221_SPI_tx
Parameters:  Array of 4 bytes to be send
Returns:     void
Description: Sends 4 byte data
*****************************************************************************/
void f_vd_4daisyChained_max7221_SPI_tx(unsigned char data[8])
{
unsigned int i;
    max7221_spi_cs = 0;		            // Bring CHIP_SELECT low
	for (i=0;i<8;i++)	
	{
	     f_vd_max7221_SPI_tx(data[i]); // send bytes
	}
	max7221_spi_cs = 1;		           // Bring CHIP_SELECT high
}

/*****************************************************************************
Name:      	f_vd_init_four_max7221     
Parameters: none                    
Returns:    none
Description: Initialize MAX7221
*****************************************************************************/
void f_vd_init_four_max7221(void)
{
unsigned char data[8];
	f_vd_init_max7221_SPI();

        /* ****************** Scan Limit *************************** */
	data[0] = max7221cmd_scn_limt;  //Command : No of displays to output
	data[1] = 0x04;                 //Data    : 5 Displays to output
	data[2] = data[0];
	data[3] = data[1];
	data[4] = data[0];
	data[5] = data[1];
	data[6] = data[0];
	data[7] = data[1];
	f_vd_4daisyChained_max7221_SPI_tx(data);
	
        /* ****************** Intensity *************************** */
	data[0] = max7221cmd_intensity;  //Command : Intensity
	data[1] = 0x07;                  //Data    : 8/16
	data[2] = data[0];
	data[3] = data[1];
	data[4] = data[0];
	data[5] = data[1];
	data[6] = data[0];
	data[7] = data[1];
	f_vd_4daisyChained_max7221_SPI_tx(data);

        /* ****************** Decode Mode *************************** */
	data[0] = max7221cmd_dec_mode;       //Command : Decode Mode
	data[1] = max7221data_decmode_noDec; //Data    : No Decoding
	data[2] = data[0];
	data[3] = data[1];
	data[4] = data[0];
	data[5] = data[1];
	data[6] = data[0];
	data[7] = data[1];
	f_vd_4daisyChained_max7221_SPI_tx(data);

        /* ****************** Shutdown/Normal Operation *************************** */
	data[0] = max7221cmd_shtdwn;         //Command : Shutdown/Normal Operation
	data[1] = max7221data_shtdwn_opertn; //Data    : Normal Operation
	data[2] = data[0];
	data[3] = data[1];
	data[4] = data[0];
	data[5] = data[1];
	data[6] = data[0];
	data[7] = data[1];
	f_vd_4daisyChained_max7221_SPI_tx(data);

	
	        /* ****************** Display Test *************************** */
	data[0] = max7221cmd_dsp_tst;         //Command : Shutdown/Normal Operation
	data[1] = max7221data_dsp_tst_no;     //Data    : No Display Test
	data[2] = data[0];
	data[3] = data[1];
	data[4] = data[0];
	data[5] = data[1];
	data[6] = data[0];
	data[7] = data[1];
	f_vd_4daisyChained_max7221_SPI_tx(data);

	        /* ****************** Blank Display *************************** */
	data[0] = max7221cmd_sel_col0;         //Command : Select Column 0
	data[1] = 0;                           //Data    : No Segment on
	data[2] = data[0];
	data[3] = data[1];
	data[4] = data[0];
	data[5] = data[1];
	data[6] = data[0];
	data[7] = data[1];
	f_vd_4daisyChained_max7221_SPI_tx(data);

		        /* ****************** Blank Display *************************** */
	data[0] = max7221cmd_sel_col1;         //Command : Select Column 1
	data[1] = 0;                           //Data    : No Segment on
	data[2] = data[0];
	data[3] = data[1];
	data[4] = data[0];
	data[5] = data[1];
	data[6] = data[0];
	data[7] = data[1];
	f_vd_4daisyChained_max7221_SPI_tx(data);

			     /* ****************** Blank Display *************************** */
	data[0] = max7221cmd_sel_col2;         //Command : Select Column 2
	data[1] = 0;                           //Data    : No Segment on
	data[2] = data[0];
	data[3] = data[1];
	data[4] = data[0];
	data[5] = data[1];
	data[6] = data[0];
	data[7] = data[1];
	f_vd_4daisyChained_max7221_SPI_tx(data);

			     /* ****************** Blank Display *************************** */
	data[0] = max7221cmd_sel_col3;         //Command : Select Column 3
	data[1] = 0;                           //Data    : No Segment on
	data[2] = data[0];
	data[3] = data[1];
	data[4] = data[0];
	data[5] = data[1];
	data[6] = data[0];
	data[7] = data[1];
	f_vd_4daisyChained_max7221_SPI_tx(data);

			     /* ****************** Blank Display *************************** */
	data[0] = max7221cmd_sel_col4;         //Command : Select Column 4
	data[1] = 0;                           //Data    : No Segment on
	data[2] = data[0];
	data[3] = data[1];
	data[4] = data[0];
	data[5] = data[1];
	data[6] = data[0];
	data[7] = data[1];
	f_vd_4daisyChained_max7221_SPI_tx(data);
}
